@@ -24,12 +24,12 @@ def getDataFields(entity, count=1000, extraParams={}):
 
     elif isinstance(entity, Resource):
         params = {
-            "protocol_value_resource_id": entity.id,
+            "multiplexing_resource_id": entity.id,
             "has_value": True
         }
     elif isinstance(entity, ResourceItem):
         params = {
-            "protocol_value_resource_item_id": entity.id,
+            "multiplexing_resource_item_id": entity.id,
             "has_value": True
         }
 
