@@ -3,6 +3,7 @@
 # Author: Thomas Bullier <thomas@labstep.com>
 
 from labstep.generic.entity.model import Entity
+from labstep.constants import UNSPECIFIED
 
 
 class JupyterNotebook(Entity):
@@ -13,7 +14,7 @@ class JupyterNotebook(Entity):
     __entityName__ = "jupyter-notebook"
     __hasGuid__ = True
 
-    def edit(self, name=None, status=None, data=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, status=UNSPECIFIED, data=UNSPECIFIED, extraParams={}):
         """
         Edit an existing JupyterNotebook.
 
