@@ -49,10 +49,7 @@ def editProtocol(
     params = {"name": name, "deleted_at": deleted_at, **extraParams}
 
     if body is not UNSPECIFIED:
-        entityRepository.editEntity(
-            ProtocolVersion(protocol.last_version, protocol.__user__),
-            {"state": body},
-        )
+        entityRepository.editEntity(protocol.last_version, {"state": body})
         protocol.update()
 
     return entityRepository.editEntity(protocol, params)
