@@ -3,12 +3,14 @@
 # Author: Barney Walker <barney@labstep.com>
 
 from labstep.generic.entity.model import Entity
+from labstep.constants import UNSPECIFIED
 
 
 class ProtocolTimer(Entity):
     __entityName__ = "protocol-timer"
+    __hasGuid__ = True
 
-    def edit(self, name=None, hours=None, minutes=None, seconds=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, hours=UNSPECIFIED, minutes=UNSPECIFIED, seconds=UNSPECIFIED, extraParams={}):
         """
         Edit an existing Protocol Timer.
 
@@ -41,11 +43,11 @@ class ProtocolTimer(Entity):
 
         params = {"name": name, **extraParams}
 
-        if hours is not None:
+        if hours is not UNSPECIFIED:
             params["hours"] = hours
-        if minutes is not None:
+        if minutes is not UNSPECIFIED:
             params["minutes"] = minutes
-        if seconds is not None:
+        if seconds is not UNSPECIFIED:
             params["seconds"] = seconds
 
         return entityRepository.editEntity(self, params)
