@@ -12,9 +12,10 @@ def getResource(user, resource_id):
 
 
 def getResources(
-    user, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
+    user, count=100, search_query=UNSPECIFIED, resource_category_id=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
 ):
     params = {"search_query": search_query,
+              "template_id": resource_category_id,
               "tag_id": tag_id, **extraParams}
     return entityRepository.getEntities(user, Resource, count, params)
 
