@@ -452,7 +452,7 @@ class User(Entity):
             extraParams=extraParams,
         )
 
-    def getResources(self, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}):
+    def getResources(self, count=100, search_query=UNSPECIFIED, resource_category_id=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of a User's Resources
         across all Workspaces on Labstep,
@@ -464,6 +464,8 @@ class User(Entity):
             The number of Resources to retrieve.
         search_query (str)
             Search for Resources with this 'name'.
+        resource_category_id (int)
+            Search for Resources in a particular category.
         tag_id (int)
             The id of a tag to filter by.
 
@@ -477,6 +479,7 @@ class User(Entity):
         ::
 
             entity = user.getResources(search_query='bacteria',
+                                       resource_category_id=123,
                                        tag_id=800)
         """
         import labstep.entities.resource.repository as resourceRepository
@@ -486,6 +489,7 @@ class User(Entity):
             count=count,
             search_query=search_query,
             tag_id=tag_id,
+            resource_category_id=resource_category_id,
             extraParams=extraParams,
         )
 
