@@ -187,7 +187,7 @@ class Workspace(Entity):
             extraParams=extraParams,
         )
 
-    def getResources(self, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}):
+    def getResources(self, count=100, search_query=UNSPECIFIED, resource_category_id=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of Resources within this specific Workspace,
         which can be filtered using the parameters:
@@ -198,6 +198,8 @@ class Workspace(Entity):
             The number of Resources to retrieve.
         search_query (str)
             Search for Resources with this 'name'.
+        resource_category_id (int)
+            Search for Resources in a particular category.
         tag_id (int)
             The id of a tag to filter by.
 
@@ -218,7 +220,7 @@ class Workspace(Entity):
         extraParams = {"group_id": self.id, **extraParams}
 
         return resourceRepository.getResources(
-            self.__user__, count, search_query, tag_id, extraParams=extraParams
+            self.__user__, count=count, search_query=search_query, resource_category_id=resource_category_id, tag_id=tag_id, extraParams=extraParams
         )
 
     def getResourceCategorys(
