@@ -21,11 +21,13 @@ def getParent():
 
     if ('LABSTEP_JUPYTER_EXPERIMENT_GUID' in os.environ.keys()):
         experimentGuid = os.environ['LABSTEP_JUPYTER_EXPERIMENT_GUID']
-        return entityRepository.getEntity(user, ExperimentProtocol, experimentGuid, useGuid=True)
+        if experimentGuid:
+            return entityRepository.getEntity(user, ExperimentProtocol, experimentGuid, useGuid=True)
 
     if('LABSTEP_JUPYTER_PROTOCOL_GUID' in os.environ.keys()):
         protocolGuid = os.environ['LABSTEP_JUPYTER_PROTOCOL_GUID']
 
-        return entityRepository.getEntity(user, ProtocolVersion, protocolGuid, useGuid=True)
+        if protocolGuid:
+            return entityRepository.getEntity(user, ProtocolVersion, protocolGuid, useGuid=True)
 
     raise Exception("No Jupyter Parent Found")
